@@ -20,10 +20,10 @@ class SpotifyPlaybackProvider(BasePlaybackProvider):
             self.backend.spotify.session.load(
                 Link.from_string(track.uri).as_track())
             self.backend.spotify.session.play(1)
-            self.backend.output.set_state('PLAYING')
+            self.backend.output.play_uri('appsrc://')
             return True
         except SpotifyError as e:
-            logger.warning('Play %s failed: %s', track.uri, e)
+            logger.info('Playback of %s failed: %s', track.uri, e)
             return False
 
     def resume(self):
