@@ -9,20 +9,33 @@ from .session import MpdSession
 
 logger = logging.getLogger('mopidy.frontends.mpd.server')
 
+def _try_ipv6_socket():
+    """Determine if system really supports IPv6"""
+    if not socket.has_ipv6:
+        return False
+    try:
+        socket.socket(socket.AF_INET6).close()
+        return True
+    except IOError, e:
+        logger.debug(u'Platform supports IPv6, but socket '
+            'creation failed, disabling: %s', e)
+    return False
+
+has_ipv6 = _try_ipv6_socket()
+
 class MpdServer(asyncore.dispatcher):
     """
     The MPD server. Creates a :class:`mopidy.frontends.mpd.session.MpdSession`
     for each client connection.
     """
 
-    def __init__(self, core_queue):
+    def __init__(self):
         asyncore.dispatcher.__init__(self)
-        self.core_queue = core_queue
 
     def start(self):
         """Start MPD server."""
         try:
-            if socket.has_ipv6:
+            if has_ipv6:
                 self.create_socket(socket.AF_INET6, socket.SOCK_STREAM)
                 # Explicitly configure socket to work for both IPv4 and IPv6
                 self.socket.setsockopt(
@@ -47,15 +60,14 @@ class MpdServer(asyncore.dispatcher):
         (client_socket, client_socket_address) = self.accept()
         logger.info(u'MPD client connection from [%s]:%s',
             client_socket_address[0], client_socket_address[1])
-        MpdSession(self, client_socket, client_socket_address,
-            self.core_queue).start()
+        MpdSession(self, client_socket, client_socket_address).start()
 
     def handle_close(self):
         """Handle end of client connection."""
         self.close()
 
     def _format_hostname(self, hostname):
-        if (socket.has_ipv6
+        if (has_ipv6
             and re.match('\d+.\d+.\d+.\d+', hostname) is not None):
             hostname = '::ffff:%s' % hostname
         return hostname
