@@ -9,7 +9,7 @@ if sys.platform == 'win32':
 from mopidy import settings
 from mopidy.backends.local import LocalBackend
 
-from tests import data_folder
+from tests import path_to_data_dir
 from tests.backends.base.library import LibraryControllerTest
 
 class LocalLibraryControllerTest(LibraryControllerTest, unittest.TestCase):
@@ -17,8 +17,8 @@ class LocalLibraryControllerTest(LibraryControllerTest, unittest.TestCase):
     backend_class = LocalBackend
 
     def setUp(self):
-        settings.LOCAL_TAG_CACHE_FILE = data_folder('library_tag_cache')
-        settings.LOCAL_MUSIC_PATH = data_folder('')
+        settings.LOCAL_TAG_CACHE_FILE = path_to_data_dir('library_tag_cache')
+        settings.LOCAL_MUSIC_PATH = path_to_data_dir('')
 
         super(LocalLibraryControllerTest, self).setUp()
 
