@@ -6,8 +6,13 @@ from mopidy.mixers.dummy import DummyMixer
 
 class AudioOutputHandlerTest(unittest.TestCase):
     def setUp(self):
-        self.b = DummyBackend(mixer_class=DummyMixer)
-        self.h = dispatcher.MpdDispatcher(backend=self.b)
+        self.b = DummyBackend.start().proxy()
+        self.mixer = DummyMixer.start().proxy()
+        self.h = dispatcher.MpdDispatcher()
+
+    def tearDown(self):
+        self.b.stop().get()
+        self.mixer.stop().get()
 
     def test_enableoutput(self):
         result = self.h.handle_request(u'enableoutput "0"')
@@ -20,6 +25,6 @@ class AudioOutputHandlerTest(unittest.TestCase):
     def test_outputs(self):
         result = self.h.handle_request(u'outputs')
         self.assert_(u'outputid: 0' in result)
-        self.assert_(u'outputname: DummyBackend' in result)
+        self.assert_(u'outputname: None' in result)
         self.assert_(u'outputenabled: 1' in result)
         self.assert_(u'OK' in result)
