@@ -3,6 +3,7 @@ import unittest
 
 from mopidy import settings as default_settings_module, SettingsError
 from mopidy.utils.settings import validate_settings, SettingsProxy
+from mopidy.utils.settings import mask_value_if_secret
 
 class ValidateSettingsTest(unittest.TestCase):
     def setUp(self):
@@ -44,7 +45,19 @@ class ValidateSettingsTest(unittest.TestCase):
     def test_two_errors_are_both_reported(self):
         result = validate_settings(self.defaults,
             {'FOO': '', 'BAR': ''})
-        self.assertEquals(len(result), 2)
+        self.assertEqual(len(result), 2)
+
+    def test_masks_value_if_secret(self):
+        secret = mask_value_if_secret('SPOTIFY_PASSWORD', 'bar')
+        self.assertEqual(u'********', secret)
+
+    def test_does_not_mask_value_if_not_secret(self):
+        not_secret = mask_value_if_secret('SPOTIFY_USERNAME', 'foo')
+        self.assertEqual('foo', not_secret)
+
+    def test_does_not_mask_value_if_none(self):
+        not_secret = mask_value_if_secret('SPOTIFY_USERNAME', None)
+        self.assertEqual(None, not_secret)
 
 
 class SettingsProxyTest(unittest.TestCase):
@@ -57,7 +70,7 @@ class SettingsProxyTest(unittest.TestCase):
 
     def test_getattr_raises_error_on_missing_setting(self):
         try:
-            test = self.settings.TEST
+            _ = self.settings.TEST
             self.fail(u'Should raise exception')
         except SettingsError as e:
             self.assertEqual(u'Setting "TEST" is not set.', e.message)
@@ -65,7 +78,7 @@ class SettingsProxyTest(unittest.TestCase):
     def test_getattr_raises_error_on_empty_setting(self):
         self.settings.TEST = u''
         try:
-            test = self.settings.TEST
+            _ = self.settings.TEST
             self.fail(u'Should raise exception')
         except SettingsError as e:
             self.assertEqual(u'Setting "TEST" is empty.', e.message)
